%define _libmoddir /lib/modules
#or command line ..
%{!?kernel: %define kernel %(uname -r)}
%define kversion %(echo %{kernel} | cut -d- -f1)
%define krelease %(echo %{kernel} | cut -d- -f2)

%define moduledir /kernel/fs/xfs
%define modules xfs.o dmapi/xfs_dmapi.o quota/xfs_quota.o

Epoch: 1
%ifarch ia64
Summary		: SMP SGI XFS filesystem kernel module(s)
%else
Summary		: UP SGI XFS filesystem kernel module(s)
%endif
Name		: kernel-module-xfs-%{kernel}
Version		: 1.3.3
Release		: 1.SL
Vendor		: Scientific Linux
Source		: xfs-kern.tar.gz
Packager	: Jaroslaw Polok <jaroslaw.polok@cern.ch>
License		: GPL
Group		: System Environment/Kernel
URL		: http://oss.sgi.com/projects/xfs
BuildRoot	: %{_tmppath}/%{name}-%{version}-buildroot

Patch1		: xfs-oot.patch
Patch2		: remove-propack-xfs-changes.patch
Patch3		: linux-2.4.22-xfs-new-odirect-test.patch
# not actually used, we swizzle the kernel instead to match
# 2.4.24 or so with do_call_directIO
Patch4		: linux-2.4.21-odirect-args.patch
Patch5		: xfs-dmapi-umoddi3-fix.patch

BuildRequires   : kernel-source 
%ifarch ia64
Requires: /boot/vmlinux-%{kernel}, modutils
%else
Requires: /boot/vmlinuz-%{kernel}, modutils
%endif
Provides: kernel-module
Provides: kernel-module-xfs = %{epoch}:%{version}-%{release}

%description
The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.

These drivers are built for kernel %{kernel}
and architecture %{_target_cpu}.

%ifnarch ia64

%package -n kernel-module-xfs-%{kernel}smp
Summary: SMP SGI XFS filesystem kernel module(s)
Group		: System Environment/Kernel
Requires: /boot/vmlinuz-%{kernel}smp, modutils
Provides: kernel-module
Provides: kernel-module-xfs = %{epoch}:%{version}-%{release}

%description -n kernel-module-xfs-%{kernel}smp
The XFS(tm) Filesystem from Silicon Graphics, Inc.
XFS is a highly scalable, high-performance journaling filesystem that provides 
rapid recovery from system crashes.

These drivers are built for kernel %{kernel}smp
and architecture %{_target_cpu}.


%endif

%package source
Summary		: The source code for the XFS filesystem kernel module.
Group		: Development/System
Requires	: kernel-source = %{kversion}-%{krelease}

%description source
The xfs-modules-source package contains the source code files for the XFS
filesystem.  When installed, this will populate the fs/xfs subdirectory
of the matching kernel-source RPM.

# suppress unused debuginfo packages
%define debug_package %{nil}

%prep
%{__rm} -rf %{buildroot}
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"

%setup -n xfs-kern

# This is what allows us to easily build xfs out of the kernel tree;
# xfs configuration also lives in here.
%patch1 -p3

# Remove the propack-specific changes
%patch2 -p3

# (hacked up) test of 2.4.22 odirect backport to older vendor kernels
%patch3 -p3

# not actually used, we swizzle the kernel instead to match
# 2.4.24 or so with do_call_directIO
#%%patch4 -p3

# remove a 64-bit divide from dmapi - this will go away when
# underlying xfs tree is updated
%patch5 -p3

%build
cd oot/
### Prepare UP kernel.
cd %{_usrsrc}/linux-%{kversion}-%{krelease}
%{__make} -s distclean &>/dev/null
%{__cp} -f configs/kernel-%{kversion}-%{_target_cpu}.config .config
%{__make} -s symlinks oldconfig dep EXTRAVERSION="-%{krelease}" &>/dev/null
cd -

%{__make} -C /usr/src/linux-%{kernel} modules SUBDIRS=$(pwd)

cd ..

%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kversion}-%{krelease}%{moduledir}
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kversion}-%{krelease}%{moduledir}

%ifnarch ia64

cd oot/

%{__make} -C /usr/src/linux-%{kernel} modules SUBDIRS=$(pwd) clean

cd ..

cd oot/
### Prepare SMP kernel.
cd %{_usrsrc}/linux-%{kversion}-%{krelease}
%{__make} -s distclean &>/dev/null
%{__cp} -f configs/kernel-%{kversion}-%{_target_cpu}-smp.config .config
%{__make} -s symlinks oldconfig dep EXTRAVERSION="-%{krelease}smp" &>/dev/null
cd -

%{__make} -C /usr/src/linux-%{kernel} modules SUBDIRS=$(pwd)

cd ..

%{__install} -d -m0755 %{buildroot}%{_libmoddir}/%{kversion}-%{krelease}smp%{moduledir}
%{__install} -m0644 %{modules} %{buildroot}%{_libmoddir}/%{kversion}-%{krelease}smp%{moduledir}

%endif

cd %{_usrsrc}/linux-%{kversion}-%{krelease}
%{__make} -s distclean &>/dev/null

%install

%ifarch i386
# Copy source files for source package
mkdir -p %{buildroot}/usr/src/linux-%{kversion}-%{krelease}/fs/xfs
find . -name Makefile -o -name \*.c -o -name \*.h	\
  | xargs cp --parents
  --target-directory=%{buildroot}/usr/src/linux-%{kversion}-%{krelease}/fs/xfs
# And get perms right
find	%{buildroot}/usr/src/linux-%{kversion}-%{krelease}/fs/xfs -type d | xargs chmod 0755
find	%{buildroot}/usr/src/linux-%{kversion}-%{krelease}/fs/xfs -type f | xargs chmod 0644
# stuff we don't ship
rm -rf	%{buildroot}/usr/src/linux-%{kversion}-%{krelease}/fs/xfs/oot
%endif

%post
/sbin/depmod -ae -F /boot/System.map-%{kernel} %{kernel}

if (stat -f / | grep -q 0x58465342) || (stat -f / | grep -q XFS); then
  echo "It appears that your root filesytem is on XFS."
  echo "Creating a new initrd /boot/initrd-%{kernel}.img"
  echo "for kernel %{kernel} with command:"
  echo "  /sbin/mkinitrd -f /boot/initrd-%{kernel}.img %{kernel}"
  echo "If you use lilo, you should re-run the lilo command."
fi

/sbin/mkinitrd -f /boot/initrd-%{kernel}.img %{kernel}

# Could do an "are you sure? y/n" thing but that might get annoying.
%preun
if (stat -f / | grep -q 0x58465342) || (stat -f / | grep -q XFS); then
  echo "It appears that your root filesystem is on XFS."
  echo "Note that kernel %{kernel} might not"
  echo "boot without this package."
fi

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%postun
/sbin/depmod -ae -F /boot/System.map-%{kernel} %{kernel}

%ifnarch ia64

%post -n kernel-module-xfs-%{kernel}smp
/sbin/depmod -ae -F /boot/System.map-%{kernel}smp %{kernel}smp

if (stat -f / | grep -q 0x58465342) || (stat -f / | grep -q XFS); then
  echo "It appears that your root filesytem is on XFS."
  echo "Creating a new initrd /boot/initrd-%{kernel}smp.img"
  echo "for kernel %{kernel}smp with command:"
  echo "  /sbin/mkinitrd -f /boot/initrd-%{kernel}smp.img %{kernel}smp"
  echo "If you use lilo, you should re-run the lilo command."
fi

/sbin/mkinitrd -f /boot/initrd-%{kernel}smp.img %{kernel}smp

# Could do an "are you sure? y/n" thing but that might get annoying.
%preun -n kernel-module-xfs-%{kernel}smp
if (stat -f / | grep -q 0x58465342) || (stat -f / | grep -q XFS); then
  echo "It appears that your root filesystem is on XFS."
  echo "Note that kernel %{kernel}smp might not"
  echo "boot without this package."
fi

%postun -n kernel-module-xfs-%{kernel}smp
/sbin/depmod -ae -F /boot/System.map-%{kernel}smp %{kernel}smp

%endif


%files
%defattr(-,root,root,0755)
%{_libmoddir}/%{kversion}-%{krelease}%{moduledir}/

%ifnarch ia64

%files -n kernel-module-xfs-%{kernel}smp
%defattr(-,root,root,0755)
%{_libmoddir}/%{kversion}-%{krelease}smp%{moduledir}/

%endif

%ifarch i386
%files source
%defattr(644,root,root,755)
/usr/src/linux-%{kversion}-%{krelease}/fs/xfs
%endif

%changelog
* Tue Jun 02 2004 Jaroslaw Polok <jaroslaw.polok@cern.ch>
- repackaged to followup Fedora Core guidelines

* Tue Apr 06 2004 Jaroslaw Polok <jaroslaw.polok@cern.ch>
- initial build
